ParseError

Enum ParseError 

pub enum ParseError {
Show 17 variants IoError(Error, String), XmlError(Error), NoRobotTag, VisualWithoutGeometry(String), GeometryWithoutShape(String), MissingParameter(String), InvalidParameter(String), NameMissing(String), MaterialWithoutColor(String), UnknownJointType(String), UnknownTag(String), ModelError(ModelError), UnknownLinkName(String), InvalidFilePath(String), InertialWithoutInertia(String), InertialWithoutMass(String), UnknownParent(String),
}
Error types that can occur while parsing an URDF file.

Variants



IoError(Error, String)

IO error occurred while reading the file.



XmlError(Error)

Error occurred while parsing XML.



NoRobotTag

The URDF file does not contain a <robot> tag.



VisualWithoutGeometry(String)

A <visual> tag is present without a corresponding <geometry> tag.



GeometryWithoutShape(String)

A <geometry> tag is present without a corresponding shape tag.



MissingParameter(String)

The given required parameter is missing in the URDF.



InvalidParameter(String)

The given parameter has an invalid value.



NameMissing(String)

A joint, link, or material is missing a name attribute.



MaterialWithoutColor(String)

A material is defined without a color.



UnknownJointType(String)

An unknown joint type was encountered.



UnknownTag(String)

An unknown tag was encountered in the URDF.



ModelError(ModelError)

An error occurred while building the model



UnknownLinkName(String)

A link is referenced that does not exist in the model.



InvalidFilePath(String)

The file path provided for a mesh is invalid.



InertialWithoutInertia(String)

An inertial tag is present without inertia data.



InertialWithoutMass(String)

An inertial tag is present without mass data.



UnknownParent(String)

A frame references a parent that does not exist.