Parser for the URDF (Unified Robot Description Format) file format.
Overview
This module provides functionality to parse URDF files and build corresponding Model and GeometryModel objects.
The parser is implemented from scratch, and does not rely on any existing URDF parsing library.
Is uses roxmltree for XML parsing, the extraction of parameters being done manually.
Joints
The following joint types are supported:
- Fixed
- Revolute
- Continuous
- Prismatic
Meshes
The parser supports mesh geometries in any format. The visualizers used might have limitations on the supported formats. Mesh paths can be resolved in three ways:
- using absolute paths;
- using ROS’s
package://(orpackage:///) syntax, as long as the package name is present in the environment variableROS_PACKAGE_PATH; - using a user-provided package directory, passed as an argument to the parsing function.
Tested models
The parser has been tested at least on all models from example-robot-data. However, some URDF features are still missing, hence some other models might not be parsed correctly yet.
Functions
- build_
models_ from_ urdf - Parses a URDF file and builds the corresponding
ModelandGeometryModel.