pub fn build_models_from_urdf(
filepath: &str,
package_dir: Option<&str>,
) -> Result<(Model, GeometryModel, GeometryModel), ParseError>Expand description
Parses a URDF file and builds the corresponding Model and GeometryModel.
Arguments
filepath- The path to the URDF file.package_dir- The path to the folder containing the mesh files referenced in the URDF.
Returns
A 3-tuple containing the Model, a collision GeometryModel, and a visualization GeometryModel objects if successful.
Returns a ParseError if there is an error during parsing.